@@ -18,7 +18,7 @@ fieldhash my %stt         => 'stt';
 fieldhash my %transitions => 'transitions';
 fieldhash my %verbose     => 'verbose';
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 # -----------------------------------------------
 
@@ -347,6 +347,7 @@ sub report
 	my($self) = @_;
 
 	$self -> log(debug => 'Entered report()');
+	$self -> log(info => 'State Transition Table');
 
 	my($stt) = $self -> stt;
 
@@ -1005,6 +1006,10 @@ Returns the object, for method chaining.
 
 =back
 
+=head2 report()
+
+Log the state transition table, at log level 'info'.
+
 =head2 reset()
 
 Resets the DFA object to the start state.
